@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.2.8   2020/11/11
+ * Version: 0.2.9   2021/04/01
  */
 
 #include "caitsith.h"
@@ -2034,7 +2034,9 @@ int cs_socket_post_accept_permission(struct socket *sock,
 static bool cs_kernel_service(void)
 {
 	/* Nothing to do if I am a kernel service. */
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 27)
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 5, 0) && LINUX_VERSION_CODE < KERNEL_VERSION(5, 12, 0)
+	return (current->flags & (PF_KTHREAD | PF_IO_WORKER)) == PF_KTHREAD;
+#elif LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 27)
 	return current->flags & PF_KTHREAD;
 #else
 	return segment_eq(get_fs(), KERNEL_DS);
